pub fn set_log_sink(sink: Option<Box<dyn Fn(c_int, &str) + Send>>)
Install (or clear, with None) a callback invoked for each idevicerestore log line as it is captured. Used to stream the restore log to a frontend.
None